@@ -1,4 +1,4 @@
-import time
+import time,os
 
 from selenium import webdriver
 import allure
@@ -14,6 +14,7 @@ class Exec:
             elif self.data[0]['browser'] == 'firefox':
                 self.driver = webdriver.Firefox()
         self.driver.implicitly_wait(10)
+        os.makedirs('screenshot')
 
 
     def goto(self):
@@ -24,7 +25,7 @@ class Exec:
                 with allure.step(f'步骤{step}:{step_text}'):
                     self.driver.get(goto_data)
                     log.info(f'步骤{step}:{step_text}')
-                    file_name = f'{strftime("%Y%m%d%H%M%S")}{step_text}.png'
+                    file_name = f'screenshot/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
                     self.driver.save_screenshot(file_name)
                     with open(file_name,'rb') as f:
                         file = f.read()
@@ -45,7 +46,7 @@ class Exec:
                     log.info(f'步骤{step}:{step_text}')
                     log.info(f'定位方式by={input_ele[:-1][0]},定位的值{input_ele[:-1][-1]}')
                     log.info(f'输入的值{input_ele[-1]}')
-                    file_name = f'{strftime("%Y%m%d%H%M%S")}{step_text}.png'
+                    file_name = f'screenshot/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
                     self.driver.save_screenshot(file_name)
                     with open(file_name, 'rb') as f:
                         file = f.read()
@@ -63,7 +64,7 @@ class Exec:
                     log.info(f'步骤{step}:{step_text}')
                     log.info(f'定位方式by={click_data[0]},定位的值{click_data[-1]}')
                     log.info('点击元素')
-                    file_name = f'{strftime("%Y%m%d%H%M%S")}{step_text}.png'
+                    file_name = f'screenshot/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
                     self.driver.save_screenshot(file_name)
                     with open(file_name, 'rb') as f:
                         file = f.read()
@@ -94,7 +95,7 @@ class Exec:
                         except Exception as error:
                             log.info(f'步骤{step}:{step_text}')
                             log.error(f'断言失败，期望值{assert_data[0]},实际值{result}')
-                            file_name = f'{strftime("%Y%m%d%H%M%S")}{step_text}断言失败.png'
+                            file_name = f'screenshot/{strftime("%Y%m%d%H%M%S")}{step_text}断言失败.png'
                             self.driver.save_screenshot(file_name)
                             with open(file_name, 'rb') as f:
                                 file = f.read()
@@ -116,7 +117,7 @@ class Exec:
                     var = text_ele[-1]
                     log.info(f'步骤{step}:{step_text}')
                     log.info(f'保存变量{var},变量值为{text_msg}')
-                    file_name = f'{strftime("%Y%m%d%H%M%S")}{step_text}.png'
+                    file_name = f'screenshot/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
                     self.driver.save_screenshot(file_name)
                     with open(file_name, 'rb') as f:
                         file = f.read()
@@ -134,7 +135,7 @@ class Exec:
                     var = text_ele[-1]
                     log.info(f'步骤{step}:{step_text}')
                     log.info(f'保存变量{var},变量值为{text_msg}')
-                    file_name = f'{strftime("%Y%m%d%H%M%S")}{step_text}.png'
+                    file_name = f'screenshot/{strftime("%Y%m%d%H%M%S")}{step_text}.png'
                     self.driver.save_screenshot(file_name)
                     with open(file_name, 'rb') as f:
                         file = f.read()
